@@ -846,12 +846,18 @@ class TestAwsLimitChecker(object):
                 'Effect': 'Allow',
                 'Resource': '*',
                 'Action': [
+                    'cloudwatch:GetMetricData',
                     'ec2:bar',
                     'ec2:foo',
                     'foo:perm1',
                     'foo:perm2',
                     'servicequotas:ListServiceQuotas',
-                    'support:*',
+                    'sts:GetCallerIdentity',
+                    'support:DescribeTrustedAdvisorCheckRefreshStatuses',
+                    'support:DescribeTrustedAdvisorCheckResult',
+                    'support:DescribeTrustedAdvisorCheckSummaries',
+                    'support:DescribeTrustedAdvisorChecks',
+                    'support:RefreshTrustedAdvisorCheck',
                     'trustedadvisor:Describe*',
                     'trustedadvisor:RefreshCheck'
                 ],
